# -*- coding: utf-8 -*-

# Copyright (C) 2008-2014 Avencall
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>

import logging
import datetime

import asyncio
from pathlib import Path

from kalyke import ApnsConfig, ApnsPushType, VoIPClient

from os import path

from xivo_agid import agid
from xivo_agid import dialplan_variables
from xivo_agid.handlers.userfeatures import UserFeatures



logger = logging.getLogger(__name__)

INIT_FB = False

try:    
    if(path.exists("/etc/xivo/cert-curl.pem")):
        INIT_FB = True
    else:
        INIT_FB = False
        logger.warn('Apple cert file not found at /etc/xivo/cert-curl.pem')
        logger.warn('Mobile App will not work on this XiVO server')
except Exception as e:
        logger.error('Error during mobile_push_notification initialization: %s', e)

def mobile_push_notification(agi, cursor, args, dry_run=False):
    if INIT_FB == False:
        agi.verbose("Exiting")
        return

    token = agi.get_variable(dialplan_variables.MOBILE_PUSH_TOKEN)
    caller = agi.get_variable(dialplan_variables.SRCNUM)

    now = datetime.datetime.now().strftime("%d/%m/%Y %H:%M:%S")

    if token != UserFeatures.NOT_REGISTERED:
        agi.verbose('Token: %s' % token)

        client = VoIPClient(
            use_sandbox=True,
            auth_key_filepath=Path("/") / "etc" / "xivo" / "cert-curl.pem",
        )

        registration_id = token

        payload = {'title':'Incoming call', 'time': now, 'caller': caller}
        config = ApnsConfig(topic="fr.wisper.xivo.voip", push_type=ApnsPushType.VOIP)
        asyncio.run(client.send_message(device_token=registration_id, payload=payload, apns_config=config))

        agi.verbose('Message: %s' % payload)


agid.register(mobile_push_notification)
